@@ -1,5 +1,5 @@
 //
-// Copyright 2017 Garrett D'Amore <garrett@damore.org>
+// Copyright 2023 Staysail Systems, Inc. <info@staysail.tech>
 // Copyright 2017 Capitar IT Group BV <info@capitar.com>
 //
 // This software is supplied under the terms of the MIT License, a
@@ -27,7 +27,6 @@
 #include "core/platform.h"
 
 #include "core/aio.h"
-#include "core/clock.h"
 #include "core/device.h"
 #include "core/file.h"
 #include "core/idhash.h"
@@ -46,11 +45,10 @@
 #include "core/strs.h"
 #include "core/taskq.h"
 #include "core/thread.h"
-#include "core/timer.h"
 #include "core/url.h"
 
 // transport needs to come after url
-#include "core/transport.h"
+#include "sp/transport.h"
 
 // These have to come after the others - particularly transport.h
 
