@@ -1,5 +1,5 @@
 //
-// Copyright 2020 Staysail Systems, Inc. <info@staysail.tech>
+// Copyright 2023 Staysail Systems, Inc. <info@staysail.tech>
 // Copyright 2018 Capitar IT Group BV <info@capitar.com>
 // Copyright 2018 QXSoftware <lh563566994@126.com>
 // Copyright 2019 Devolutions <info@devolutions.net>
@@ -22,15 +22,6 @@
 
 #include "http_api.h"
 
-static int  http_server_sys_init(void);
-static void http_server_sys_fini(void);
-
-static nni_initializer http_server_initializer = {
-	.i_init = http_server_sys_init,
-	.i_fini = http_server_sys_fini,
-	.i_once = 0,
-};
-
 struct nng_http_handler {
 	nni_list_node   node;
 	char *          uri;
@@ -82,8 +73,8 @@ struct nng_http_server {
 	nni_list             handlers;
 	nni_list             conns;
 	nni_mtx              mtx;
-	nni_cv               cv;
 	bool                 closed;
+	bool                 fini; // if nni_http_server_fini was called
 	nni_aio *            accaio;
 	nng_stream_listener *listener;
 	int                  port; // native order
@@ -279,8 +270,9 @@ nni_http_handler_set_method(nni_http_handler *h, const char *method)
 	return (0);
 }
 
-static nni_list http_servers;
-static nni_mtx  http_servers_lk;
+static nni_list http_servers =
+    NNI_LIST_INITIALIZER(http_servers, nni_http_server, node);
+static nni_mtx http_servers_lk = NNI_MTX_INITIALIZER;
 
 static void
 http_sc_reap(void *arg)
@@ -309,8 +301,8 @@ http_sc_reap(void *arg)
 	if (nni_list_node_active(&sc->node)) {
 		nni_list_remove(&s->conns, sc);
 	}
-	if (nni_list_empty(&s->conns)) {
-		nni_cv_wake(&s->cv);
+	if (nni_list_empty(&s->conns) && (s->fini)) {
+		nni_reap(&http_server_reap_list, s);
 	}
 	nni_mtx_unlock(&s->mtx);
 
@@ -463,10 +455,11 @@ http_uri_canonify(char *path)
 			c += http_hexval(tmp[2]);
 			*dst++ = c;
 			tmp += 3;
+		} else {
+			// garbage in, garbage out
+			*dst++ = c;
+			tmp++;
 		}
-		// garbage in, garbage out
-		*dst++ = c;
-		tmp++;
 	}
 	*dst = '\0';
 
@@ -493,6 +486,7 @@ http_sconn_error(http_sconn *sc, uint16_t err)
 		if (nni_http_res_set_header(res, "Connection", "close") != 0) {
 			nni_http_res_free(res);
 			http_sconn_close(sc);
+			return;
 		}
 	}
 	sc->res = res;
@@ -915,13 +909,7 @@ http_server_fini(nni_http_server *s)
 	nni_aio_stop(s->accaio);
 
 	nni_mtx_lock(&s->mtx);
-	if (!nni_list_empty(&s->conns)) {
-		// Try to reap later, after the connections are done reaping.
-		// (Note, connections will all have been closed already.)
-		nni_reap(&http_server_reap_list, s);
-		nni_mtx_unlock(&s->mtx);
-		return;
-	}
+	NNI_ASSERT(nni_list_empty(&s->conns));
 	nng_stream_listener_free(s->listener);
 	while ((h = nni_list_first(&s->handlers)) != NULL) {
 		nni_list_remove(&s->handlers, h);
@@ -938,7 +926,6 @@ http_server_fini(nni_http_server *s)
 	nni_mtx_fini(&s->errors_mtx);
 
 	nni_aio_free(s->accaio);
-	nni_cv_fini(&s->cv);
 	nni_mtx_fini(&s->mtx);
 	nni_strfree(s->hostname);
 	NNI_FREE_STRUCT(s);
@@ -964,7 +951,6 @@ http_server_init(nni_http_server **serverp, const nni_url *url)
 	}
 	nni_mtx_init(&s->mtx);
 	nni_mtx_init(&s->errors_mtx);
-	nni_cv_init(&s->cv, &s->mtx);
 	NNI_LIST_INIT(&s->handlers, nni_http_handler, node);
 	NNI_LIST_INIT(&s->conns, http_sconn, node);
 
@@ -1001,8 +987,6 @@ nni_http_server_init(nni_http_server **serverp, const nni_url *url)
 	int              rv;
 	nni_http_server *s;
 
-	nni_initialize(&http_server_initializer);
-
 	nni_mtx_lock(&http_servers_lk);
 	NNI_LIST_FOREACH (&http_servers, s) {
 		if ((!s->closed) && (atoi(url->u_port) == s->port) &&
@@ -1056,10 +1040,8 @@ nni_http_server_start(nni_http_server *s)
 }
 
 static void
-http_server_stop(nni_http_server *s)
+http_server_close(nni_http_server *s)
 {
-	http_sconn *sc;
-
 	if (s->closed) {
 		return;
 	}
@@ -1071,29 +1053,48 @@ http_server_stop(nni_http_server *s)
 	if (s->listener) {
 		nng_stream_listener_close(s->listener);
 	}
+}
+
+static void
+http_server_stop(nni_http_server *s)
+{
+	http_sconn *sc;
+
+	http_server_close(s);
 
 	// Stopping the server is a hard stop -- it aborts any work
 	// being done by clients.  (No graceful shutdown).
 	NNI_LIST_FOREACH (&s->conns, sc) {
 		http_sc_close_locked(sc);
 	}
-
-	while (!nni_list_empty(&s->conns)) {
-		nni_cv_wait(&s->cv);
-	}
 }
 
 void
 nni_http_server_stop(nni_http_server *s)
 {
 	nni_mtx_lock(&s->mtx);
-	s->starts--;
+	if (s->starts != 0) {
+		s->starts--;
+	}
 	if (s->starts == 0) {
 		http_server_stop(s);
 	}
 	nni_mtx_unlock(&s->mtx);
 }
 
+void
+nni_http_server_close(nni_http_server *s)
+{
+	nni_mtx_lock(&s->mtx);
+	if (s->starts != 0) {
+		s->starts--;
+	}
+	if (s->starts == 0) {
+		http_server_close(s);
+	}
+	nni_mtx_unlock(&s->mtx);
+}
+
 static int
 http_server_set_err(nni_http_server *s, uint16_t code, void *body, size_t len)
 {
@@ -1164,7 +1165,7 @@ nni_http_server_res_error(nni_http_server *s, nni_http_res *res)
 	http_error *epage;
 	char *      body = NULL;
 	char *      html = NULL;
-	size_t      len;
+	size_t      len  = 0;
 	uint16_t    code = nni_http_res_get_status(res);
 	int         rv;
 
@@ -1558,7 +1559,10 @@ http_handle_dir(nni_aio *aio)
 	}
 
 	for (uri = uri + len; *uri != '\0'; uri++) {
-		if (*uri == '/') {
+		if (*uri == '?') {
+			// Skip URI parameters
+			break;
+		} else if (*uri == '/') {
 			strcpy(dst, NNG_PLATFORM_DIR_SEP);
 			dst += sizeof(NNG_PLATFORM_DIR_SEP) - 1;
 		} else {
@@ -1915,27 +1919,18 @@ nni_http_server_fini(nni_http_server *s)
 {
 	nni_mtx_lock(&http_servers_lk);
 	s->refcnt--;
-	if (s->refcnt == 0) {
-		nni_mtx_lock(&s->mtx);
-		http_server_stop(s);
-		nni_mtx_unlock(&s->mtx);
-		nni_list_remove(&http_servers, s);
+	if (s->refcnt != 0) {
+		nni_mtx_unlock(&http_servers_lk);
+		return;
+	}
+	nni_list_remove(&http_servers, s);
+	nni_mtx_unlock(&http_servers_lk);
+
+	nni_mtx_lock(&s->mtx);
+	http_server_stop(s);
+	s->fini = true;
+	if (nni_list_empty(&s->conns)) {
 		nni_reap(&http_server_reap_list, s);
 	}
-	nni_mtx_unlock(&http_servers_lk);
-}
-
-static int
-http_server_sys_init(void)
-{
-	NNI_LIST_INIT(&http_servers, nni_http_server, node);
-	nni_mtx_init(&http_servers_lk);
-	return (0);
-}
-
-static void
-http_server_sys_fini(void)
-{
-	nni_reap_drain();
-	nni_mtx_fini(&http_servers_lk);
+	nni_mtx_unlock(&s->mtx);
 }
