@@ -1,5 +1,5 @@
 //
-// Copyright 2021 Staysail Systems, Inc. <info@staysail.tech>
+// Copyright 2022 Staysail Systems, Inc. <info@staysail.tech>
 // Copyright 2018 Capitar IT Group BV <info@capitar.com>
 // Copyright 2020 Dirac Research <robert.bielik@dirac.com>
 //
@@ -25,7 +25,7 @@
 #include "convey.h"
 #include "core/nng_impl.h"
 
-const char *doc1 = "<html><body>Someone <b>is</b> home!</body</html>";
+const char *doc1 = "<html><body>Someone <b>is</b> home!</body></html>";
 const char *doc2 = "This is a text file.";
 const char *doc3 = "<html><body>This is doc number 3.</body></html>";
 const char *doc4 = "<html><body>Whoops, Errored!</body></html>";
@@ -191,7 +191,7 @@ TestMain("HTTP Server", {
 		char     urlstr[48];
 		nng_url *url;
 
-		trantest_next_address(portbuf, "%u");
+		trantest_next_address(portbuf, "");
 
 		snprintf(
 		    urlstr, sizeof(urlstr), "http://127.0.0.1:%s", portbuf);
@@ -295,7 +295,7 @@ TestMain("HTTP Server", {
 		char *   subdir1;
 		char *   subdir2;
 
-		trantest_next_address(urlstr, "http://127.0.0.1:%u");
+		trantest_next_address(urlstr, "http://127.0.0.1:");
 		So(nng_url_parse(&url, urlstr) == 0);
 		So(nng_http_server_hold(&s, url) == 0);
 		So((tmpdir = nni_plat_temp_dir()) != NULL);
@@ -387,6 +387,24 @@ TestMain("HTTP Server", {
 			nng_free(data, size);
 		});
 
+		Convey("Named file with URI parameters works", {
+			char     fullurl[256];
+			void *   data;
+			size_t   size;
+			uint16_t stat;
+			char *   ctype;
+
+			snprintf(
+			    fullurl, sizeof(fullurl), "%s/file.txt?param=123456", urlstr);
+			So(httpget(fullurl, &data, &size, &stat, &ctype) == 0);
+			So(stat == NNG_HTTP_STATUS_OK);
+			So(size == strlen(doc2));
+			So(memcmp(data, doc2, size) == 0);
+			So(strcmp(ctype, "text/plain") == 0);
+			nni_strfree(ctype);
+			nng_free(data, size);
+		});
+
 		Convey("Missing index gives 404", {
 			char     fullurl[256];
 			void *   data;
@@ -440,6 +458,7 @@ TestMain("HTTP Server", {
 			nng_url_free(curl);
 			nng_free(data, size);
 		});
+
 		Convey("Version 0.9 gives 505", {
 			char          fullurl[256];
 			void *        data;
@@ -462,6 +481,7 @@ TestMain("HTTP Server", {
 			nng_url_free(curl);
 			nng_free(data, size);
 		});
+
 		Convey("Missing Host gives 400", {
 			char          fullurl[256];
 			void *        data;
@@ -497,7 +517,7 @@ TestMain("HTTP Server", {
 		char *   subdir1;
 		char *   subdir2;
 
-		trantest_next_address(urlstr, "http://127.0.0.1:%u");
+		trantest_next_address(urlstr, "http://127.0.0.1:");
 		So(nng_url_parse(&url, urlstr) == 0);
 		So(nng_http_server_hold(&s, url) == 0);
 		So((tmpdir = nni_plat_temp_dir()) != NULL);
@@ -643,6 +663,7 @@ TestMain("HTTP Server", {
 			nng_url_free(curl);
 			nng_free(data, size);
 		});
+
 		Convey("Version 0.9 gives 505", {
 			char          fullurl[256];
 			void *        data;
@@ -665,6 +686,7 @@ TestMain("HTTP Server", {
 			nng_url_free(curl);
 			nng_free(data, size);
 		});
+
 		Convey("Missing Host gives 400", {
 			char          fullurl[256];
 			void *        data;
@@ -698,7 +720,7 @@ TestMain("HTTP Server", {
 		char *   file1;
 		char *   file2;
 
-		trantest_next_address(urlstr, "http://127.0.0.1:%u");
+		trantest_next_address(urlstr, "http://127.0.0.1:");
 		So(nng_url_parse(&url, urlstr) == 0);
 		So(nng_http_server_hold(&s, url) == 0);
 		So((tmpdir = nni_plat_temp_dir()) != NULL);
@@ -788,7 +810,7 @@ TestMain("HTTP Server", {
 		char     urlstr[32];
 		nng_url *url;
 
-		trantest_next_address(urlstr, "http://127.0.0.1:%u");
+		trantest_next_address(urlstr, "http://127.0.0.1:");
 		So(nng_url_parse(&url, urlstr) == 0);
 		So(nng_http_server_hold(&s, url) == 0);
 
@@ -859,7 +881,7 @@ TestMain("HTTP Server", {
 		char     urlstr[32];
 		nng_url *url;
 
-		trantest_next_address(urlstr, "http://127.0.0.1:%u");
+		trantest_next_address(urlstr, "http://127.0.0.1:");
 		So(nng_url_parse(&url, urlstr) == 0);
 		So(nng_http_server_hold(&s, url) == 0);
 
@@ -978,7 +1000,7 @@ TestMain("HTTP Server", {
 		char     urlstr[32];
 		nng_url *url;
 
-		trantest_next_address(urlstr, "http://127.0.0.1:%u");
+		trantest_next_address(urlstr, "http://127.0.0.1:");
 		So(nng_url_parse(&url, urlstr) == 0);
 		So(nng_http_server_hold(&s, url) == 0);
 
